;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "lsp-pyright" "20250905.136"
  "Python LSP client using Pyright."
  '((emacs    "28.1")
    (lsp-mode "7.0")
    (dash     "2.18.0")
    (ht       "2.0"))
  :url "https://github.com/emacs-lsp/lsp-pyright"
  :commit "3756ff971797ae04fc43ca29c66ba4d854eff038"
  :revdesc "3756ff971797"
  :keywords '("languages" "tools" "lsp"))
